@@ -3,12 +3,13 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.16';
+our $VERSION = '1.17';
 
 use Carp;
 use Fcntl qw(:flock);
 use File::Find::Rule;
 use File::Temp;
+use POSIX qw(uname);
 
 sub new {
     return bless {}, shift;
@@ -27,8 +28,6 @@ sub read {
         $self->_config(file => $file, testing => $testing);
     }
 
-    $self->{is_read} = 1;
-
     $file = $self->{file};
     $testing = $self->{testing};
 
@@ -37,6 +36,7 @@ sub read {
     }
 
     $self->recsep($file);
+    $self->{is_read} = 1;
 
     my $fh;
 
@@ -83,7 +83,18 @@ sub write {
     
     my $wfh = $self->_open($file, 'w');
 
-    flock $wfh, LOCK_EX;
+    # certain FreeBSD versions on amd64 don't work
+    # with flock()
+
+    my @os = uname();
+
+    unless (
+            $os[0] eq 'FreeBSD' 
+            && ($os[2] eq '10.1-RELEASE' || $os[2] eq '9.2-RELEASE')
+            && $os[-1] eq 'amd64'
+        ){
+        flock $wfh, LOCK_EX;
+    }
 
     $recsep = defined $recsep ? $recsep : $self->{recsep};
 
@@ -194,11 +205,18 @@ sub dir {
     return @files if $self->{list};
 
     for my $file (@files){
-        my @contents = $self->read($file);
+
+        my $fh = $self->read($file);
+        my $wfh = $self->tempfile;
+
+        while(<$fh>){
+            print $wfh $_;
+        }
+        close $fh;
 
         $self->write(
                     file => $file, 
-                    contents => \@contents, 
+                    contents => $wfh,
                     recsep => defined $recsep ? $recsep : $self->platform_recsep,
                 );
     }
@@ -295,9 +313,6 @@ sub platform_recsep {
     }
 }
 sub tempfile {
-
-    my $self = shift;
-    
     my $wfh = File::Temp->new(UNLINK => 1);
     return $wfh;
 }
@@ -389,7 +404,7 @@ sub _open {
 sub _temp_filename {
 
     my $self = shift;
-    
+
     my $temp_fh = File::Temp->new(UNLINK => 1);
 
     my $file = $temp_fh->filename;
@@ -579,9 +594,7 @@ Steve Bertrand, C<< <steveb at cpan.org> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-file-edit-portable at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=File-Edit-Portable>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to L<https://github.com/stevieb9/mock-sub/issues>
 
 =head1 REPOSITORY
 
